@@ -53,6 +53,9 @@ class Allocation(base.APIBase):
     node_uuid = wsme.wsattr(types.uuid, readonly=True)
     """The UUID of the node this allocation belongs to"""
 
+    node = wsme.wsattr(wtypes.text)
+    """The node to backfill the allocation for (POST only)"""
+
     name = wsme.wsattr(wtypes.text)
     """The logical name for this allocation"""
 
@@ -65,8 +68,7 @@ class Allocation(base.APIBase):
     last_error = wsme.wsattr(wtypes.text, readonly=True)
     """Last error that happened to this allocation"""
 
-    resource_class = wsme.wsattr(wtypes.StringType(max_length=80),
-                                 mandatory=True)
+    resource_class = wsme.wsattr(wtypes.StringType(max_length=80))
     """Requested resource class for this allocation"""
 
     # NOTE(dtantsur): candidate_nodes is a list of UUIDs on the database level,
@@ -93,6 +95,8 @@ class Allocation(base.APIBase):
     @staticmethod
     def _convert_with_links(allocation, url):
         """Add links to the allocation."""
+        # This field is only used in POST, never return it.
+        allocation.node = wsme.Unset
         allocation.links = [
             link.Link.make_link('self', url, 'allocations', allocation.uuid),
             link.Link.make_link('bookmark', url, 'allocations',
@@ -181,8 +185,7 @@ class AllocationCollection(collection.Collection):
             Allocation.convert_with_links(p, fields=fields, sanitize=False)
             for p in rpc_allocations
         ]
-        collection.next = collection.get_next(limit, url=url, fields=fields,
-                                              **kwargs)
+        collection.next = collection.get_next(limit, url=url, **kwargs)
 
         for item in collection.allocations:
             item.sanitize(fields=fields)
@@ -197,6 +200,11 @@ class AllocationCollection(collection.Collection):
         return sample
 
 
+class AllocationPatchType(types.JsonPatchType):
+
+    _api_base = Allocation
+
+
 class AllocationsController(pecan.rest.RestController):
     """REST controller for allocations."""
 
@@ -330,10 +338,6 @@ class AllocationsController(pecan.rest.RestController):
         cdict = context.to_policy_values()
         policy.authorize('baremetal:allocation:create', cdict, cdict)
 
-        if allocation.node_uuid is not wtypes.Unset:
-            msg = _("Cannot set node_uuid when creating an allocation")
-            raise exception.Invalid(msg)
-
         if (allocation.name
                 and not api_utils.is_valid_logical_name(allocation.name)):
             msg = _("Cannot create allocation with invalid name "
@@ -344,6 +348,27 @@ class AllocationsController(pecan.rest.RestController):
             for trait in allocation.traits:
                 api_utils.validate_trait(trait)
 
+        node = None
+        if allocation.node is not wtypes.Unset:
+            if api_utils.allow_allocation_backfill():
+                try:
+                    node = api_utils.get_rpc_node(allocation.node)
+                except exception.NodeNotFound as exc:
+                    exc.code = http_client.BAD_REQUEST
+                    raise
+            else:
+                msg = _("Cannot set node when creating an allocation "
+                        "in this API version")
+                raise exception.Invalid(msg)
+
+        if not allocation.resource_class:
+            if node:
+                allocation.resource_class = node.resource_class
+            else:
+                msg = _("The resource_class field is mandatory when not "
+                        "backfilling")
+                raise exception.Invalid(msg)
+
         if allocation.candidate_nodes:
             # Convert nodes from names to UUIDs and check their validity
             try:
@@ -361,10 +386,19 @@ class AllocationsController(pecan.rest.RestController):
 
         # NOTE(yuriyz): UUID is mandatory for notifications payload
         if not all_dict.get('uuid'):
-            all_dict['uuid'] = uuidutils.generate_uuid()
+            if node and node.instance_uuid:
+                # When backfilling without UUID requested, assume that the
+                # target instance_uuid is the desired UUID
+                all_dict['uuid'] = node.instance_uuid
+            else:
+                all_dict['uuid'] = uuidutils.generate_uuid()
 
         new_allocation = objects.Allocation(context, **all_dict)
-        topic = pecan.request.rpcapi.get_random_topic()
+        if node:
+            new_allocation.node_id = node.id
+            topic = pecan.request.rpcapi.get_topic_for(node)
+        else:
+            topic = pecan.request.rpcapi.get_random_topic()
 
         notify.emit_start_notification(context, new_allocation, 'create')
         with notify.handle_error_notification(context, new_allocation,
@@ -378,6 +412,61 @@ class AllocationsController(pecan.rest.RestController):
                                                  new_allocation.uuid)
         return Allocation.convert_with_links(new_allocation)
 
+    def _validate_patch(self, patch):
+        allowed_fields = ['name', 'extra']
+        for p in patch:
+            path = p['path'].split('/')[1]
+            if path not in allowed_fields:
+                msg = _("Cannot update %s in an allocation. Only 'name' and "
+                        "'extra' are allowed to be updated.")
+                raise exception.Invalid(msg % p['path'])
+
+    @METRICS.timer('AllocationsController.patch')
+    @wsme.validate(types.uuid, [AllocationPatchType])
+    @expose.expose(Allocation, types.uuid_or_name, body=[AllocationPatchType])
+    def patch(self, allocation_ident, patch):
+        """Update an existing allocation.
+
+        :param allocation_ident: UUID or logical name of an allocation.
+        :param patch: a json PATCH document to apply to this allocation.
+        """
+        if not api_utils.allow_allocation_update():
+            raise webob_exc.HTTPMethodNotAllowed(_(
+                "The API version does not allow updating allocations"))
+        context = pecan.request.context
+        cdict = context.to_policy_values()
+        policy.authorize('baremetal:allocation:update', cdict, cdict)
+        self._validate_patch(patch)
+        names = api_utils.get_patch_values(patch, '/name')
+        for name in names:
+            if name and not api_utils.is_valid_logical_name(name):
+                msg = _("Cannot update allocation with invalid name "
+                        "'%(name)s'") % {'name': name}
+                raise exception.Invalid(msg)
+        rpc_allocation = api_utils.get_rpc_allocation_with_suffix(
+            allocation_ident)
+        allocation_dict = rpc_allocation.as_dict()
+        allocation = Allocation(**api_utils.apply_jsonpatch(allocation_dict,
+                                                            patch))
+        # Update only the fields that have changed
+        for field in objects.Allocation.fields:
+            try:
+                patch_val = getattr(allocation, field)
+            except AttributeError:
+                # Ignore fields that aren't exposed in the API
+                continue
+            if patch_val == wtypes.Unset:
+                patch_val = None
+            if rpc_allocation[field] != patch_val:
+                rpc_allocation[field] = patch_val
+
+        notify.emit_start_notification(context, rpc_allocation, 'update')
+        with notify.handle_error_notification(context,
+                                              rpc_allocation, 'update'):
+            rpc_allocation.save()
+        notify.emit_end_notification(context, rpc_allocation, 'update')
+        return Allocation.convert_with_links(rpc_allocation)
+
     @METRICS.timer('AllocationsController.delete')
     @expose.expose(None, types.uuid_or_name,
                    status_code=http_client.NO_CONTENT)
