@@ -370,7 +370,7 @@ def is_valid_node_name(name):
 
     Check to see that the provided node name is valid, and isn't a UUID.
 
-    :param: name: the node name to check.
+    :param name: the node name to check.
     :returns: True if the name is valid, False otherwise.
     """
     return is_valid_logical_name(name) and not uuidutils.is_uuid_like(name)
@@ -1161,3 +1161,19 @@ def allow_build_configdrive():
     Version 1.56 of the API added support for building configdrive.
     """
     return pecan.request.version.minor >= versions.MINOR_56_BUILD_CONFIGDRIVE
+
+
+def allow_allocation_update():
+    """Check if updating an existing allocation is allowed or not.
+
+    Version 1.57 of the API added support for updating an allocation.
+    """
+    return pecan.request.version.minor >= versions.MINOR_57_ALLOCATION_UPDATE
+
+
+def allow_allocation_backfill():
+    """Check if backfilling allocations is allowed.
+
+    Version 1.58 of the API added support for backfilling allocations.
+    """
+    return pecan.request.version.minor >= versions.MINOR_58_ALLOCATION_BACKFILL
