@@ -34,6 +34,10 @@ from ironic.common.i18n import _
 from ironic.common import utils
 
 IMAGE_CHUNK_SIZE = 1024 * 1024  # 1mb
+# NOTE(kaifeng) Image will be truncated to 2GiB by sendfile,
+# we use a large chunk size here for a better performance
+# while keep the chunk size less than the size limit.
+SENDFILE_CHUNK_SIZE = 1024 * 1024 * 1024  # 1Gb
 LOG = log.getLogger(__name__)
 
 
@@ -211,9 +215,17 @@ class FileImageService(BaseImageService):
                 os.link(source_image_path, dest_image_path)
             else:
                 filesize = os.path.getsize(source_image_path)
+                offset = 0
                 with open(source_image_path, 'rb') as input_img:
-                    sendfile.sendfile(image_file.fileno(), input_img.fileno(),
-                                      0, filesize)
+                    while offset < filesize:
+                        # TODO(kaifeng) Use os.sendfile() and remove sendfile
+                        # dependency when python2 support is dropped.
+                        count = min(SENDFILE_CHUNK_SIZE, filesize - offset)
+                        nbytes_out = sendfile.sendfile(image_file.fileno(),
+                                                       input_img.fileno(),
+                                                       offset,
+                                                       count)
+                        offset += nbytes_out
         except Exception as e:
             raise exception.ImageDownloadFailed(image_href=image_href,
                                                 reason=six.text_type(e))
