@@ -274,8 +274,7 @@ def create_isolinux_image_for_uefi(output_file, kernel, ramdisk,
                 grub_cfg = os.path.join(tmpdir, grub_rel_path)
 
                 uefi_path_info = {
-                    esp_image: e_img_rel_path,
-                    grub_cfg: grub_rel_path
+                    esp_image: e_img_rel_path
                 }
 
             else:
@@ -531,8 +530,8 @@ def is_whole_disk_image(ctx, instance_info):
 def _mount_deploy_iso(deploy_iso, mountdir):
     """This function opens up the deploy iso used for deploy.
 
-    :param: deploy_iso: path to the deploy iso where its
-                        contents are fetched to.
+    :param deploy_iso: path to the deploy iso where its
+                       contents are fetched to.
     :raises: ImageCreationFailed if mount fails.
     :returns: a tuple consisting of - 1. a dictionary containing
                                          the values as required
