@@ -320,7 +320,7 @@ def create_pxe_config(task, pxe_options, template=None, ipxe_enabled=False):
         # in the MAC addresses and DHCP files being written, and
         # we can remove IP address creation for the grub use
         # case, considering that will ease removal of elilo support.
-        except exception.FailedToGetIPAddressOnPort as e:
+        except exception.FailedToGetIPaddressesOnPort as e:
             if CONF.dhcp.dhcp_provider != 'none':
                 with excutils.save_and_reraise_exception():
                     LOG.error('Unable to create boot config, IP address '
