@@ -47,7 +47,7 @@ from ironic.common.i18n import _
 # NOTE(rloo): We need a list, not just the latest version, for the DB queries
 # that filter for objects that are not in particular versions; for more info,
 # see comments after L1128 of
-# https://review.openstack.org/#/c/408556/52/ironic/db/sqlalchemy/api.py.
+# https://review.opendev.org/#/c/408556/52/ironic/db/sqlalchemy/api.py.
 #
 # There should always be a 'master' entry that reflects the objects in the
 # master branch.
@@ -162,8 +162,25 @@ RELEASE_MAPPING = {
             'VolumeTarget': ['1.0'],
         }
     },
+    '12.2': {
+        'api': '1.58',
+        'rpc': '1.48',
+        'objects': {
+            'Allocation': ['1.0'],
+            'Node': ['1.32'],
+            'Conductor': ['1.3'],
+            'Chassis': ['1.3'],
+            'DeployTemplate': ['1.1'],
+            'Port': ['1.9'],
+            'Portgroup': ['1.4'],
+            'Trait': ['1.0'],
+            'TraitList': ['1.0'],
+            'VolumeConnector': ['1.0'],
+            'VolumeTarget': ['1.0'],
+        }
+    },
     'master': {
-        'api': '1.56',
+        'api': '1.58',
         'rpc': '1.48',
         'objects': {
             'Allocation': ['1.0'],
