@@ -44,45 +44,39 @@ class SwiftAPI(object):
     """Underlying Swift connection object."""
 
     def __init__(self):
-        """Initialize the connection with swift or radosgw
+        """Initialize the connection with swift
 
         :raises: ConfigInvalid if required keystone authorization credentials
          with swift are missing.
         """
         params = {'retries': CONF.swift.swift_max_retries}
-        if CONF.deploy.object_store_endpoint_type == 'radosgw':
-            params.update({'authurl': CONF.swift.auth_url,
-                           'user': CONF.swift.username,
-                           'key': CONF.swift.password})
-        else:
-            # NOTE(pas-ha) swiftclient still (as of 3.3.0) does not use
-            # (adapter-based) SessionClient, and uses the passed in session
-            # only to resolve endpoint and get a token,
-            # but not to make further requests to Swift itself (LP 1736135).
-            # Thus we need to deconstruct back all the adapter- and
-            # session-related args as loaded by keystoneauth from config
-            # to pass them to the client explicitly.
-            # TODO(pas-ha) re-write this when swiftclient is brought on par
-            # with other OS clients re auth plugins, sessions and adapters
-            # support.
-            # TODO(pas-ha) pass the context here and use token from context
-            # with service auth
-            params['session'] = session = get_swift_session()
-            adapter = keystone.get_adapter('swift', session=session)
-            params['os_options'] = {
-                'object_storage_url': adapter.get_endpoint()}
-            # deconstruct back session-related options
-            params['timeout'] = session.timeout
-            if session.verify is False:
-                params['insecure'] = True
-            elif isinstance(session.verify, six.string_types):
-                params['cacert'] = session.verify
-            if session.cert:
-                # NOTE(pas-ha) although setting cert as path to single file
-                # with both client cert and key is supported by Session,
-                # keystoneauth loading always sets the session.cert
-                # as tuple of cert and key.
-                params['cert'], params['cert_key'] = session.cert
+        # NOTE(pas-ha) swiftclient still (as of 3.3.0) does not use
+        # (adapter-based) SessionClient, and uses the passed in session
+        # only to resolve endpoint and get a token,
+        # but not to make further requests to Swift itself (LP 1736135).
+        # Thus we need to deconstruct back all the adapter- and
+        # session-related args as loaded by keystoneauth from config
+        # to pass them to the client explicitly.
+        # TODO(pas-ha) re-write this when swiftclient is brought on par
+        # with other OS clients re auth plugins, sessions and adapters
+        # support.
+        # TODO(pas-ha) pass the context here and use token from context
+        # with service auth
+        params['session'] = session = get_swift_session()
+        adapter = keystone.get_adapter('swift', session=session)
+        params['os_options'] = {'object_storage_url': adapter.get_endpoint()}
+        # deconstruct back session-related options
+        params['timeout'] = session.timeout
+        if session.verify is False:
+            params['insecure'] = True
+        elif isinstance(session.verify, six.string_types):
+            params['cacert'] = session.verify
+        if session.cert:
+            # NOTE(pas-ha) although setting cert as path to single file
+            # with both client cert and key is supported by Session,
+            # keystoneauth loading always sets the session.cert
+            # as tuple of cert and key.
+            params['cert'], params['cert_key'] = session.cert
 
         self.connection = swift_client.Connection(**params)
 
@@ -103,7 +97,7 @@ class SwiftAPI(object):
             operation = _("put container")
             raise exception.SwiftOperationError(operation=operation, error=e)
 
-        with open(filename, "r") as fileobj:
+        with open(filename, "rb") as fileobj:
 
             try:
                 obj_uuid = self.connection.put_object(container,
