@@ -77,15 +77,6 @@ api_opts = [
 ]
 
 driver_opts = [
-    cfg.ListOpt('enabled_drivers',
-                default=[],
-                help=_('This option is left for a start up check only. '
-                       'Any non-empty value will prevent the conductor '
-                       'from starting.'),
-                deprecated_for_removal=True,
-                deprecated_reason=_('Hardware types should be used instead '
-                                    'of classic drivers. They are enabled '
-                                    'via the enabled_hardware_types option.')),
     cfg.ListOpt('enabled_hardware_types',
                 default=['ipmi'],
                 help=_('Specify the list of hardware types to load during '
@@ -151,6 +142,7 @@ driver_opts = [
                 default=['cinder', 'noop'],
                 help=_ENABLED_IFACE_HELP.format('storage')),
     cfg.StrOpt('default_storage_interface',
+               default='noop',
                help=_DEFAULT_IFACE_HELP.format('storage')),
     cfg.ListOpt('enabled_vendor_interfaces',
                 default=['ipmitool', 'no-vendor'],
@@ -165,7 +157,13 @@ exc_log_opts = [
                 help=_('Used if there is a formatting error when generating '
                        'an exception message (a programming error). If True, '
                        'raise an exception; if False, use the unformatted '
-                       'message.')),
+                       'message.'),
+                deprecated_for_removal=True,
+                deprecated_reason=_('Same option in the ironic_lib section '
+                                    'should be used instead.')),
+    cfg.IntOpt('log_in_db_max_size', default=4096,
+               help=_('Max number of characters of any node '
+                      'last_error/maintenance_reason pushed to database.')),
 ]
 
 hash_opts = [
@@ -183,15 +181,6 @@ hash_opts = [
                       'smooth in most cases. The default is suitable for up '
                       'to a few hundred conductors. Configuring for too many '
                       'partitions has a negative impact on CPU usage.')),
-    cfg.IntOpt('hash_distribution_replicas',
-               default=1,
-               help=_('[Experimental Feature] '
-                      'Number of hosts to map onto each hash partition. '
-                      'Setting this to more than one will cause additional '
-                      'conductor services to prepare deployment environments '
-                      'and potentially allow the Ironic cluster to recover '
-                      'more quickly if a conductor instance is terminated.'),
-               deprecated_for_removal=True),
     cfg.IntOpt('hash_ring_reset_interval',
                default=15,
                help=_('Time (in seconds) after which the hash ring is '
