@@ -213,7 +213,7 @@ class BaseInterface(object):
                         'argsinfo': method._clean_step_argsinfo,
                         'interface': instance.interface_type}
                 instance.clean_steps.append(step)
-            elif getattr(method, '_is_deploy_step', False):
+            if getattr(method, '_is_deploy_step', False):
                 # Create a DeployStep to represent this method
                 step = {'step': method.__name__,
                         'priority': method._deploy_step_priority,
@@ -1004,32 +1004,22 @@ class InspectInterface(BaseInterface):
             driver=task.node.driver, extension='abort')
 
 
+def cache_bios_settings(func):
+    """A decorator to cache bios settings after running the function.
+
+    :param func: Function or method to wrap.
+    """
+    @six.wraps(func)
+    def wrapped(self, task, *args, **kwargs):
+        result = func(self, task, *args, **kwargs)
+        self.cache_bios_settings(task)
+        return result
+    return wrapped
+
+
 class BIOSInterface(BaseInterface):
     interface_type = 'bios'
 
-    def __new__(cls, *args, **kwargs):
-        # Wrap the apply_configuration and factory_reset into a decorator
-        # which call cache_bios_settings() to update the node's BIOS setting
-        # table after apply_configuration and factory_reset have finished.
-
-        super_new = super(BIOSInterface, cls).__new__
-        instance = super_new(cls, *args, **kwargs)
-
-        def wrapper(func):
-            @six.wraps(func)
-            def wrapped(task, *args, **kwargs):
-                result = func(task, *args, **kwargs)
-                instance.cache_bios_settings(task)
-                return result
-            return wrapped
-
-        for n, method in inspect.getmembers(instance, inspect.ismethod):
-            if n == "apply_configuration":
-                instance.apply_configuration = wrapper(method)
-            elif n == "factory_reset":
-                instance.factory_reset = wrapper(method)
-        return instance
-
     @abc.abstractmethod
     def apply_configuration(self, task, settings):
         """Validate & apply BIOS settings on the given node.
@@ -1344,6 +1334,14 @@ class NetworkInterface(BaseInterface):
         """
         pass
 
+    def need_power_on(self, task):
+        """Check if ironic node must be powered on before applying network changes
+
+        :param task: A TaskManager instance.
+        :returns: Boolean.
+        """
+        return False
+
 
 @six.add_metaclass(abc.ABCMeta)
 class StorageInterface(BaseInterface):
@@ -1440,7 +1438,7 @@ def clean_step(priority, abortable=False, argsinfo=None):
     For automated cleaning, only steps with priorities greater than 0 are
     used. These steps are ordered by priority from highest value to lowest
     value. For steps with the same priority, they are ordered by driver
-    interface priority (see conductor.manager.CLEANING_INTERFACE_PRIORITY).
+    interface priority (see conductor.steps.CLEANING_INTERFACE_PRIORITY).
     execute_clean_step() will be called on each step.
 
     For manual cleaning, the clean steps will be executed in a similar fashion
@@ -1516,7 +1514,7 @@ def deploy_step(priority, argsinfo=None):
     Only steps with priorities greater than 0 are used.
     These steps are ordered by priority from highest value to lowest
     value. For steps with the same priority, they are ordered by driver
-    interface priority (see conductor.manager.DEPLOYING_INTERFACE_PRIORITY).
+    interface priority (see conductor.steps.DEPLOYING_INTERFACE_PRIORITY).
     execute_deploy_step() will be called on each step.
 
     Decorated deploy steps must take as the only positional argument, a
