@@ -32,7 +32,6 @@ from ironic.conductor import steps as conductor_steps
 from ironic.conductor import utils as manager_utils
 from ironic.conf import CONF
 from ironic.drivers.modules import agent_client
-from ironic.drivers.modules import boot_mode_utils
 from ironic.drivers.modules import deploy_utils
 from ironic.drivers import utils as driver_utils
 
@@ -367,9 +366,6 @@ class HeartbeatMixin(object):
                     else:
                         node.touch_provisioning()
                 else:
-                    # The exceptions from RPC are not possible as we using cast
-                    # here
-                    manager_utils.notify_conductor_resume_deploy(task)
                     node.touch_provisioning()
             elif node.provision_state == states.CLEANWAIT:
                 node.touch_provisioning()
@@ -780,12 +776,23 @@ class AgentDeployMixin(HeartbeatMixin):
         node = task.node
         LOG.debug('Configuring local boot for node %s', node.uuid)
 
-        # For whole disk images it is not necessary that the root_uuid
-        # be provided since the bootloaders on the disk will be used
-        whole_disk_image = node.driver_internal_info.get('is_whole_disk_image')
-        if ((root_uuid and not whole_disk_image) or
-            (whole_disk_image and
-             boot_mode_utils.get_boot_mode(node) == 'uefi')):
+        # If the target RAID configuration is set to 'software' for the
+        # 'controller', we need to trigger the installation of grub on
+        # the holder disks of the desired Software RAID.
+        internal_info = node.driver_internal_info
+        raid_config = node.target_raid_config
+        logical_disks = raid_config.get('logical_disks', [])
+        software_raid = False
+        for logical_disk in logical_disks:
+            if logical_disk['controller'] == 'software':
+                LOG.debug('Node %s has a Software RAID configuration',
+                          node.uuid)
+                software_raid = True
+                root_uuid = internal_info.get('root_uuid_or_disk_id')
+                break
+
+        whole_disk_image = internal_info.get('is_whole_disk_image')
+        if software_raid or (root_uuid and not whole_disk_image):
             LOG.debug('Installing the bootloader for node %(node)s on '
                       'partition %(part)s, EFI system partition %(efi)s',
                       {'node': node.uuid, 'part': root_uuid,
@@ -795,20 +802,11 @@ class AgentDeployMixin(HeartbeatMixin):
                 efi_system_part_uuid=efi_system_part_uuid,
                 prep_boot_part_uuid=prep_boot_part_uuid)
             if result['command_status'] == 'FAILED':
-                if not whole_disk_image:
-                    msg = (_("Failed to install a bootloader when "
-                             "deploying node %(node)s. Error: %(error)s") %
-                           {'node': node.uuid,
-                            'error': result['command_error']})
-                    log_and_raise_deployment_error(task, msg)
-                else:
-                    # Its possible the install will fail if the IPA image
-                    # has not been updated, log this and continue
-                    LOG.info('Could not install bootloader for whole disk '
-                             'image for node %(node)s, Error: %(error)s"',
-                             {'node': node.uuid,
-                              'error': result['command_error']})
-                    return
+                msg = (_("Failed to install a bootloader when "
+                         "deploying node %(node)s. Error: %(error)s") %
+                       {'node': node.uuid,
+                        'error': result['command_error']})
+                log_and_raise_deployment_error(task, msg)
 
         try:
             persistent = True
