@@ -12,7 +12,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import imp
 import inspect
 import os
 import sys
@@ -45,10 +44,20 @@ class TestExposedAPIMethodsCheckPolicy(test_base.TestCase):
 
     def _test(self, module):
         module_path = os.path.abspath(sys.modules[module].__file__)
-        # NOTE(vdrok): coverage runs on compiled .pyc files, which breaks
-        # load_source. Strip c and o letters from the end of the module path,
-        # just in case someone tries to use .pyo or .pyc for whatever reason
-        imp.load_source(uuidutils.generate_uuid(), module_path.rstrip('co'))
+        # (rpittau) we can use importlib only with python >= 3.3
+        # we can remove the if-else block once python 2.x is gone
+        if sys.version_info[:2] >= (3, 3):
+            from importlib.machinery import SourceFileLoader
+            SourceFileLoader(uuidutils.generate_uuid(),
+                             module_path).load_module()
+        else:
+            import imp
+            # NOTE(vdrok): coverage runs on compiled .pyc files, which breaks
+            # load_source. Strip c and o letters from the end of the module
+            # path, just in case someone tries to use .pyo or .pyc for whatever
+            # reason
+            imp.load_source(uuidutils.generate_uuid(),
+                            module_path.rstrip('co'))
 
         for func in self.exposed_methods:
             src = inspect.getsource(func)
@@ -59,7 +68,7 @@ class TestExposedAPIMethodsCheckPolicy(test_base.TestCase):
                           'context.to_policy_values call not found in '
                           'exposed method %s' % func)
 
-    def test_chasis_api_policy(self):
+    def test_chassis_api_policy(self):
         self._test('ironic.api.controllers.v1.chassis')
 
     def test_driver_api_policy(self):
