@@ -66,7 +66,8 @@ class TestNeutronClient(base.TestCase):
                                             session=mock.sentinel.session,
                                             auth=auth, retries=2,
                                             endpoint_override=url,
-                                            global_request_id='global')
+                                            global_request_id='global',
+                                            timeout=45)
 
     @mock.patch('ironic.common.context.RequestContext', autospec=True)
     def test_get_neutron_client_with_token(self, mock_ctxt, mock_client_init,
@@ -84,7 +85,8 @@ class TestNeutronClient(base.TestCase):
             auth=mock.sentinel.sauth,
             retries=2,
             endpoint_override='neutron_url',
-            global_request_id=ctxt.global_id)
+            global_request_id=ctxt.global_id,
+            timeout=45)
 
         # testing handling of default url_timeout
         mock_session.assert_called_once_with('neutron', timeout=10)
@@ -268,23 +270,23 @@ class TestNeutronNetworkActions(db_base.DbTestCase):
 
         self.assertIsNone(
             neutron._verify_security_groups(sg_ids, client))
-        client.list_security_groups.assert_called_once_with(
-            fields='id', id=sg_ids)
+        client.list_security_groups.assert_called_once_with()
 
     def test_verify_sec_groups_less_than_configured(self):
         sg_ids = []
         for i in range(2):
             sg_ids.append(uuidutils.generate_uuid())
 
-        expected_vals = {'security_groups': [{'id': sg_ids[0]}]}
+        expected_vals = {'security_groups': []}
+        for sg in sg_ids:
+            expected_vals['security_groups'].append({'id': sg})
 
         client = mock.MagicMock()
         client.list_security_groups.return_value = expected_vals
 
         self.assertIsNone(
             neutron._verify_security_groups(sg_ids[:1], client))
-        client.list_security_groups.assert_called_once_with(
-            fields='id', id=sg_ids[:1])
+        client.list_security_groups.assert_called_once_with()
 
     def test_verify_sec_groups_more_than_configured(self):
         sg_ids = []
@@ -298,8 +300,7 @@ class TestNeutronNetworkActions(db_base.DbTestCase):
         self.assertRaises(
             exception.NetworkError,
             neutron._verify_security_groups, sg_ids, client)
-        client.list_security_groups.assert_called_once_with(
-            fields='id', id=sg_ids)
+        client.list_security_groups.assert_called_once_with()
 
     def test_verify_sec_groups_no_sg_from_neutron(self):
         sg_ids = []
@@ -312,8 +313,7 @@ class TestNeutronNetworkActions(db_base.DbTestCase):
         self.assertRaises(
             exception.NetworkError,
             neutron._verify_security_groups, sg_ids, client)
-        client.list_security_groups.assert_called_once_with(
-            fields='id', id=sg_ids)
+        client.list_security_groups.assert_called_once_with()
 
     def test_verify_sec_groups_exception_by_neutronclient(self):
         sg_ids = []
@@ -328,8 +328,7 @@ class TestNeutronNetworkActions(db_base.DbTestCase):
             exception.NetworkError,
             "Could not retrieve security groups",
             neutron._verify_security_groups, sg_ids, client)
-        client.list_security_groups.assert_called_once_with(
-            fields='id', id=sg_ids)
+        client.list_security_groups.assert_called_once_with()
 
     def test_add_ports_with_client_id_to_network(self):
         self._test_add_ports_to_network(is_client_id=True)
