@@ -29,7 +29,6 @@ from ironic.drivers import base as drivers_base
 from ironic.drivers.modules import agent
 from ironic.drivers.modules import agent_base_vendor
 from ironic.drivers.modules import agent_client
-from ironic.drivers.modules import boot_mode_utils
 from ironic.drivers.modules import deploy_utils
 from ironic.drivers.modules import fake
 from ironic.drivers.modules import pxe
@@ -139,8 +138,6 @@ class HeartbeatMixinTest(AgentDeployMixinBaseTest):
             self.assertFalse(cd_mock.called)
             rti_mock.assert_called_once_with(self.deploy, task)
 
-    @mock.patch.object(manager_utils,
-                       'notify_conductor_resume_deploy', autospec=True)
     @mock.patch.object(agent_base_vendor.HeartbeatMixin,
                        'in_core_deploy_step', autospec=True)
     @mock.patch.object(agent_base_vendor.HeartbeatMixin,
@@ -154,8 +151,7 @@ class HeartbeatMixinTest(AgentDeployMixinBaseTest):
     def test_heartbeat_not_in_core_deploy_step(self, rti_mock, cd_mock,
                                                deploy_is_done_mock,
                                                deploy_started_mock,
-                                               in_deploy_mock,
-                                               in_resume_deploy_mock):
+                                               in_deploy_mock):
         # Check that heartbeats do not trigger deployment actions when not in
         # the deploy.deploy step.
         in_deploy_mock.return_value = False
@@ -174,7 +170,6 @@ class HeartbeatMixinTest(AgentDeployMixinBaseTest):
             self.assertFalse(deploy_is_done_mock.called)
             self.assertFalse(cd_mock.called)
             self.assertFalse(rti_mock.called)
-            self.assertTrue(in_resume_deploy_mock.called)
 
     @mock.patch.object(agent_base_vendor.HeartbeatMixin, 'continue_deploy',
                        autospec=True)
@@ -1040,25 +1035,33 @@ class AgentDeployMixinTest(AgentDeployMixinBaseTest):
             try_set_boot_device_mock.assert_called_once_with(
                 task, boot_devices.DISK, persistent=True)
 
-    @mock.patch.object(boot_mode_utils, 'get_boot_mode',
-                       autospec=True)
     @mock.patch.object(deploy_utils, 'try_set_boot_device', autospec=True)
     @mock.patch.object(agent_client.AgentClient, 'install_bootloader',
                        autospec=True)
-    def test_configure_local_boot_no_root_uuid_whole_disk(
-            self, install_bootloader_mock, try_set_boot_device_mock,
-            boot_mode_mock):
+    def test_configure_local_boot_on_software_raid(
+            self, install_bootloader_mock, try_set_boot_device_mock):
         with task_manager.acquire(self.context, self.node['uuid'],
                                   shared=False) as task:
             task.node.driver_internal_info['is_whole_disk_image'] = True
-            boot_mode_mock.return_value = 'uefi'
-            self.deploy.configure_local_boot(
-                task, root_uuid=None,
-                efi_system_part_uuid='efi-system-part-uuid')
-            install_bootloader_mock.assert_called_once_with(
-                mock.ANY, task.node, root_uuid=None,
-                efi_system_part_uuid='efi-system-part-uuid',
-                prep_boot_part_uuid=None)
+            task.node.target_raid_config = {
+                "logical_disks": [
+                    {
+                        "size_gb": 100,
+                        "raid_level": "1",
+                        "controller": "software",
+                    },
+                    {
+                        "size_gb": 'MAX',
+                        "raid_level": "0",
+                        "controller": "software",
+                    }
+                ]
+            }
+
+            self.deploy.configure_local_boot(task)
+            self.assertTrue(install_bootloader_mock.called)
+            try_set_boot_device_mock.assert_called_once_with(
+                task, boot_devices.DISK, persistent=True)
 
     @mock.patch.object(deploy_utils, 'try_set_boot_device', autospec=True)
     @mock.patch.object(agent_client.AgentClient, 'install_bootloader',
@@ -1070,8 +1073,6 @@ class AgentDeployMixinTest(AgentDeployMixinBaseTest):
             driver_info = task.node.driver_info
             driver_info['force_persistent_boot_device'] = 'Default'
             task.node.driver_info = driver_info
-            driver_info['force_persistent_boot_device'] = 'Always'
-            task.node.driver_internal_info['is_whole_disk_image'] = False
             self.deploy.configure_local_boot(task)
             self.assertFalse(install_bootloader_mock.called)
             try_set_boot_device_mock.assert_called_once_with(
@@ -1087,7 +1088,6 @@ class AgentDeployMixinTest(AgentDeployMixinBaseTest):
             driver_info = task.node.driver_info
             driver_info['force_persistent_boot_device'] = 'Always'
             task.node.driver_info = driver_info
-            task.node.driver_internal_info['is_whole_disk_image'] = False
             self.deploy.configure_local_boot(task)
             self.assertFalse(install_bootloader_mock.called)
             try_set_boot_device_mock.assert_called_once_with(
@@ -1103,7 +1103,6 @@ class AgentDeployMixinTest(AgentDeployMixinBaseTest):
             driver_info = task.node.driver_info
             driver_info['force_persistent_boot_device'] = 'Never'
             task.node.driver_info = driver_info
-            task.node.driver_internal_info['is_whole_disk_image'] = False
             self.deploy.configure_local_boot(task)
             self.assertFalse(install_bootloader_mock.called)
             try_set_boot_device_mock.assert_called_once_with(
@@ -1504,7 +1503,7 @@ class AgentDeployMixinTest(AgentDeployMixinBaseTest):
     @mock.patch.object(agent_client.AgentClient, 'get_commands_status',
                        autospec=True)
     def test_continue_cleaning_fail(self, status_mock, error_mock):
-        # Test the a failure puts the node in CLEANFAIL
+        # Test that a failure puts the node in CLEANFAIL
         status_mock.return_value = [{
             'command_status': 'FAILED',
             'command_name': 'execute_clean_step',
